summaryrefslogtreecommitdiffstats
path: root/kftpgrabber/src/widgets/widgetlister.h
diff options
context:
space:
mode:
Diffstat (limited to 'kftpgrabber/src/widgets/widgetlister.h')
-rw-r--r--kftpgrabber/src/widgets/widgetlister.h40
1 files changed, 20 insertions, 20 deletions
diff --git a/kftpgrabber/src/widgets/widgetlister.h b/kftpgrabber/src/widgets/widgetlister.h
index 8aac58f..40192eb 100644
--- a/kftpgrabber/src/widgets/widgetlister.h
+++ b/kftpgrabber/src/widgets/widgetlister.h
@@ -36,23 +36,23 @@
#ifndef KFTPWIDGETSWIDGETLISTER_H
#define KFTPWIDGETSWIDGETLISTER_H
-#include <qwidget.h>
-#include <qptrlist.h>
+#include <ntqwidget.h>
+#include <ntqptrlist.h>
-class QPushButton;
-class QVBoxLayout;
-class QHBox;
+class TQPushButton;
+class TQVBoxLayout;
+class TQHBox;
namespace KFTPWidgets {
/**
- * This class has been adopted from KDEPIM with slight functional and style
+ * This class has been adopted from TDEPIM with slight functional and style
* changes.
*
* @author Jernej Kos
* @author Marc Mutz <marc@mutz.com>
*/
-class WidgetLister : public QWidget
+class WidgetLister : public TQWidget
{
Q_OBJECT
public:
@@ -63,7 +63,7 @@ public:
* @param minWidgets Minimum number of widgets in the list
* @param maxWidgets Maximum number of widgets in the list
*/
- WidgetLister(QWidget* parent, int minWidgets, int maxWidgets);
+ WidgetLister(TQWidget* parent, int minWidgets, int maxWidgets);
/**
* Class destructor.
@@ -112,12 +112,12 @@ protected:
* what it is asked to do. You want to reimplement this method if you want to
* initialize the the widget when showing it on screen. Make sure you call this
* implementaion, though, since you cannot put the widget on screen from derived
* classes (@p m_layout is private). Make sure the parent of the QWidget to add is
* this WidgetLister.
*
* @param widget The widget that should be added
*/
- virtual void addWidget(QWidget *widget = 0);
+ virtual void addWidget(TQWidget *widget = 0);
/**
* Removes a single (always the last) widget. Doesn't care if there are still only
@@ -134,24 +134,24 @@ protected:
*
* @param widget The widget that should be cleared
*/
- virtual void clearWidget(QWidget *widget);
+ virtual void clearWidget(TQWidget *widget);
/**
* This method should return a new widget to add to the widget list.
*
* @param parent The parent widget
- * @return A valid QWidget
+ * @return A valid TQWidget
*/
- virtual QWidget *createWidget(QWidget *parent);
+ virtual TQWidget *createWidget(TQWidget *parent);
protected:
- QPtrList<QWidget> m_widgetList;
+ TQPtrList<TQWidget> m_widgetList;
int m_minWidgets;
int m_maxWidgets;
signals:
/**
* This signal is emitted whenever a widget gets added.
*/
- void widgetAdded(QWidget *widget);
+ void widgetAdded(TQWidget *widget);
/**
* This signal is emitted whenever a widget gets removed.
@@ -165,11 +165,11 @@ signals:
private:
void enableControls();
- QPushButton *m_buttonMore;
- QPushButton *m_buttonFewer;
- QPushButton *m_buttonClear;
- QVBoxLayout *m_layout;
- QHBox *m_buttonBox;
+ TQPushButton *m_buttonMore;
+ TQPushButton *m_buttonFewer;
+ TQPushButton *m_buttonClear;
+ TQVBoxLayout *m_layout;
+ TQHBox *m_buttonBox;
};
}
@@ -112,12 +112,12 @@ protected:
* initialize the the widget when showing it on screen. Make sure you call this
* implementaion, though, since you cannot put the widget on screen from derived
- * classes (@p m_layout is private). Make sure the parent of the QWidget to add is
+ * classes (@p m_layout is private). Make sure the parent of the TQWidget to add is
* this WidgetLister.
*